@@ -367,10 +367,20 @@ startLambdaName <- as.character(attr(x, "NameForLambda"))
       lev <- (lev-.hat.WX(w,x)) # subtract  the linear since is already fitted 
       var <- lev/w              # the variance of the smootherz
      # se <-  sqrt(diag(solve(XWX + lambda * t(D) %*% D)))
-  if (is.null(xeval)) # if no prediction 
+coefSmo <- list(   coef = fit$beta,
+                     fv = fv, 
+                 lambda = lambda, 
+                    edf = fit$edf, 
+                  sigb2 = tau2, 
+                  sige2 = sig2,
+                   sigb = if (is.null(tau2)) NA else sqrt(tau2),
+                   sige = if (is.null(sig2)) NA else sqrt(sig2),
+                 method = control$method)
+class(coefSmo) <- c("cy", "pb") 
+if (is.null(xeval)) # if no prediction 
     {
      list(fitted.values=fv, residuals=y-fv, var=var, nl.df =fit$edf-1,
-          lambda=lambda, coefSmo=list(coef=fit$beta, lambda=lambda, edf=fit$edf, tau2=tau2, sig2=sig2, method=control$method) )
+          lambda=lambda, coefSmo=coefSmo)
     }                            
 else # for prediction 
     {
@@ -381,3 +391,10 @@ else # for prediction
     }    
 }
 #----------------------------------------------------------------------------------------
+print.cy  <- function (x, digits = max(3, getOption("digits") - 3), ...) 
+{   
+  cat("Cycle P-spline fit using the gamlss function cy() \n")
+  cat("Degrees of Freedom for the fit :", x$edf, "\n")
+  cat("Random effect parameter sigma_b:", format(signif(x$sigb)), "\n")  
+  cat("Smoothing parameter lambda     :", format(signif(x$lambda)), "\n") 
+}
\ No newline at end of file
